# SWARM-SLR

## Stage I
[SWARM-SLR_Stage_I.ipynb](SWARM-SLR_Stage_I.ipynb)

## Stage II
[SWARM-SLR_Stage_II.ipynb](SWARM-SLR_Stage_II.ipynb)

## Stage III
[SWARM-SLR_Stage_III.ipynb](SWARM-SLR_Stage_III.ipynb)

## Stage IV
[SWARM-SLR_Stage_IV.ipynb](SWARM-SLR_Stage_IV.ipynb)